@@ -16,20 +16,21 @@
  * <http://www.gnu.org/licenses/>.
  */
 
-#ifndef LIBVIRT_NETDEV_BANDWIDTH_CONF_H
-# define LIBVIRT_NETDEV_BANDWIDTH_CONF_H
+#pragma once
 
-# include "internal.h"
-# include "virnetdevbandwidth.h"
-# include "virbuffer.h"
-# include "virxml.h"
-# include "domain_conf.h"
+#include "internal.h"
+#include "virnetdevbandwidth.h"
+#include "virbuffer.h"
+#include "virxml.h"
+#include "domain_conf.h"
 
 int virNetDevBandwidthParse(virNetDevBandwidthPtr *bandwidth,
+                            unsigned int *class_id,
                             xmlNodePtr node,
                             bool allowFloor)
     ATTRIBUTE_NONNULL(1) ATTRIBUTE_RETURN_CHECK;
 int virNetDevBandwidthFormat(virNetDevBandwidthPtr def,
+                             unsigned int class_id,
                              virBufferPtr buf);
 
 void virDomainClearNetBandwidth(virDomainObjPtr vm)
@@ -56,5 +57,3 @@ static inline bool virNetDevSupportBandwidth(virDomainNetType type)
     }
     return false;
 }
-
-#endif /* LIBVIRT_NETDEV_BANDWIDTH_CONF_H */
