@@ -17,12 +17,12 @@
  * <http://www.gnu.org/licenses/>.
  */
 
-#ifndef LIBVIRT_VIRNETWORKOBJ_H
-# define LIBVIRT_VIRNETWORKOBJ_H
+#pragma once
 
-# include "internal.h"
+#include "internal.h"
 
-# include "network_conf.h"
+#include "network_conf.h"
+#include "virnetworkportdef.h"
 
 typedef struct _virNetworkObj virNetworkObj;
 typedef virNetworkObj *virNetworkObjPtr;
@@ -156,6 +156,39 @@ void
 virNetworkObjRemoveInactive(virNetworkObjListPtr nets,
                             virNetworkObjPtr net);
 
+int
+virNetworkObjAddPort(virNetworkObjPtr net,
+                     virNetworkPortDefPtr portdef,
+                     const char *stateDir);
+
+char *
+virNetworkObjGetPortStatusDir(virNetworkObjPtr net,
+                              const char *stateDir);
+
+virNetworkPortDefPtr
+virNetworkObjLookupPort(virNetworkObjPtr net,
+                        const unsigned char *uuid);
+
+int
+virNetworkObjDeletePort(virNetworkObjPtr net,
+                        const unsigned char *uuid,
+                        const char *stateDir);
+
+int
+virNetworkObjDeleteAllPorts(virNetworkObjPtr net,
+                            const char *stateDir);
+
+typedef bool
+(*virNetworkPortListFilter)(virConnectPtr conn,
+                            virNetworkDefPtr def,
+                            virNetworkPortDefPtr portdef);
+
+int
+virNetworkObjPortListExport(virNetworkPtr net,
+                            virNetworkObjPtr obj,
+                            virNetworkPortPtr **ports,
+                            virNetworkPortListFilter filter);
+
 int
 virNetworkObjSaveStatus(const char *statusDir,
                         virNetworkObjPtr net) ATTRIBUTE_RETURN_CHECK;
@@ -220,5 +253,3 @@ virNetworkObjListNumOfNetworks(virNetworkObjListPtr nets,
 void
 virNetworkObjListPrune(virNetworkObjListPtr nets,
                        unsigned int flags);
-
-#endif /* LIBVIRT_VIRNETWORKOBJ_H */
