@@ -156,9 +156,6 @@ virStorageVolObjDispose(void *opaque)
 {
     virStorageVolObjPtr obj = opaque;
 
-    if (!obj)
-        return;
-
     virStorageVolDefFree(obj->voldef);
 }
 
@@ -190,9 +187,6 @@ virStorageVolObjListDispose(void *opaque)
 {
     virStorageVolObjListPtr vols = opaque;
 
-    if (!vols)
-        return;
-
     virHashFree(vols->objsKey);
     virHashFree(vols->objsName);
     virHashFree(vols->objsPath);
@@ -362,9 +356,6 @@ virStoragePoolObjDispose(void *opaque)
 {
     virStoragePoolObjPtr obj = opaque;
 
-    if (!obj)
-        return;
-
     virStoragePoolObjClearVols(obj);
     virObjectUnref(obj->volumes);
 
@@ -619,6 +610,9 @@ virStoragePoolSourceFindDuplicateDevices(virStoragePoolObjPtr obj,
 void
 virStoragePoolObjClearVols(virStoragePoolObjPtr obj)
 {
+    if (!obj->volumes)
+        return;
+
     virHashRemoveAll(obj->volumes->objsKey);
     virHashRemoveAll(obj->volumes->objsName);
     virHashRemoveAll(obj->volumes->objsPath);
