@@ -19,43 +19,42 @@
  * <http://www.gnu.org/licenses/>.
  */
 
-#ifndef LIBVIRT_LIBXL_CONF_H
-# define LIBVIRT_LIBXL_CONF_H
+#pragma once
 
-# include <libxl.h>
+#include <libxl.h>
 
-# include "internal.h"
-# include "libvirt_internal.h"
-# include "virdomainobjlist.h"
-# include "domain_event.h"
-# include "capabilities.h"
-# include "configmake.h"
-# include "virportallocator.h"
-# include "virobject.h"
-# include "virchrdev.h"
-# include "virhostdev.h"
-# include "locking/lock_manager.h"
-# include "virfirmware.h"
-# include "libxl_capabilities.h"
-# include "libxl_logger.h"
+#include "internal.h"
+#include "libvirt_internal.h"
+#include "virdomainobjlist.h"
+#include "domain_event.h"
+#include "capabilities.h"
+#include "configmake.h"
+#include "virportallocator.h"
+#include "virobject.h"
+#include "virchrdev.h"
+#include "virhostdev.h"
+#include "locking/lock_manager.h"
+#include "virfirmware.h"
+#include "libxl_capabilities.h"
+#include "libxl_logger.h"
 
-# define LIBXL_DRIVER_NAME "xenlight"
-# define LIBXL_VNC_PORT_MIN  5900
-# define LIBXL_VNC_PORT_MAX  65535
+#define LIBXL_DRIVER_NAME "xenlight"
+#define LIBXL_VNC_PORT_MIN  5900
+#define LIBXL_VNC_PORT_MAX  65535
 
-# define LIBXL_MIGRATION_PORT_MIN  49152
-# define LIBXL_MIGRATION_PORT_MAX  49216
+#define LIBXL_MIGRATION_PORT_MIN  49152
+#define LIBXL_MIGRATION_PORT_MAX  49216
 
-# define LIBXL_CONFIG_BASE_DIR SYSCONFDIR "/libvirt"
-# define LIBXL_CONFIG_DIR SYSCONFDIR "/libvirt/libxl"
-# define LIBXL_AUTOSTART_DIR LIBXL_CONFIG_DIR "/autostart"
-# define LIBXL_STATE_DIR LOCALSTATEDIR "/run/libvirt/libxl"
-# define LIBXL_LOG_DIR LOCALSTATEDIR "/log/libvirt/libxl"
-# define LIBXL_LIB_DIR LOCALSTATEDIR "/lib/libvirt/libxl"
-# define LIBXL_SAVE_DIR LIBXL_LIB_DIR "/save"
-# define LIBXL_DUMP_DIR LIBXL_LIB_DIR "/dump"
-# define LIBXL_CHANNEL_DIR LIBXL_LIB_DIR "/channel/target"
-# define LIBXL_BOOTLOADER_PATH "pygrub"
+#define LIBXL_CONFIG_BASE_DIR SYSCONFDIR "/libvirt"
+#define LIBXL_CONFIG_DIR SYSCONFDIR "/libvirt/libxl"
+#define LIBXL_AUTOSTART_DIR LIBXL_CONFIG_DIR "/autostart"
+#define LIBXL_STATE_DIR LOCALSTATEDIR "/run/libvirt/libxl"
+#define LIBXL_LOG_DIR LOCALSTATEDIR "/log/libvirt/libxl"
+#define LIBXL_LIB_DIR LOCALSTATEDIR "/lib/libvirt/libxl"
+#define LIBXL_SAVE_DIR LIBXL_LIB_DIR "/save"
+#define LIBXL_DUMP_DIR LIBXL_LIB_DIR "/dump"
+#define LIBXL_CHANNEL_DIR LIBXL_LIB_DIR "/channel/target"
+#define LIBXL_BOOTLOADER_PATH "pygrub"
 
 
 typedef struct _libxlDriverPrivate libxlDriverPrivate;
@@ -141,12 +140,12 @@ struct _libxlDriverPrivate {
     virLockManagerPluginPtr lockManager;
 };
 
-# define LIBXL_SAVE_MAGIC "libvirt-xml\n \0 \r"
-# ifdef LIBXL_HAVE_SRM_V2
-#  define LIBXL_SAVE_VERSION 2
-# else
-#  define LIBXL_SAVE_VERSION 1
-# endif
+#define LIBXL_SAVE_MAGIC "libvirt-xml\n \0 \r"
+#ifdef LIBXL_HAVE_SRM_V2
+# define LIBXL_SAVE_VERSION 2
+#else
+# define LIBXL_SAVE_VERSION 1
+#endif
 
 typedef struct _libxlSavefileHeader libxlSavefileHeader;
 typedef libxlSavefileHeader *libxlSavefileHeaderPtr;
@@ -193,23 +192,23 @@ libxlMakeVfb(virPortAllocatorRangePtr graphicsports,
 int
 libxlMakePCI(virDomainHostdevDefPtr hostdev, libxl_device_pci *pcidev);
 
-# ifdef LIBXL_HAVE_PVUSB
+#ifdef LIBXL_HAVE_PVUSB
 int
 libxlMakeUSBController(virDomainControllerDefPtr controller,
                        libxl_device_usbctrl *usbctrl);
 
 int
 libxlMakeUSB(virDomainHostdevDefPtr hostdev, libxl_device_usbdev *usbdev);
-# endif
+#endif
 
 virDomainXMLOptionPtr
 libxlCreateXMLConf(void);
 
-# ifdef LIBXL_HAVE_DEVICE_CHANNEL
-#  define LIBXL_ATTR_UNUSED
-# else
-#  define LIBXL_ATTR_UNUSED ATTRIBUTE_UNUSED
-# endif
+#ifdef LIBXL_HAVE_DEVICE_CHANNEL
+# define LIBXL_ATTR_UNUSED
+#else
+# define LIBXL_ATTR_UNUSED ATTRIBUTE_UNUSED
+#endif
 int
 libxlBuildDomainConfig(virPortAllocatorRangePtr graphicsports,
                        virDomainDefPtr def,
@@ -227,5 +226,3 @@ libxlDriverUnlock(libxlDriverPrivatePtr driver)
 {
     virMutexUnlock(&driver->lock);
 }
-
-#endif /* LIBVIRT_LIBXL_CONF_H */
