@@ -162,7 +162,6 @@ virLogDaemonNew(virLogDaemonConfigPtr config, bool privileged)
     if (!(srv = virNetServerNew("virtlogd", 1,
                                 0, 0, 0, config->max_clients,
                                 config->max_clients, -1, 0,
-                                NULL,
                                 virLogDaemonClientNew,
                                 virLogDaemonClientPreExecRestart,
                                 virLogDaemonClientFree,
@@ -177,7 +176,6 @@ virLogDaemonNew(virLogDaemonConfigPtr config, bool privileged)
     if (!(srv = virNetServerNew("admin", 1,
                                 0, 0, 0, config->admin_max_clients,
                                 config->admin_max_clients, -1, 0,
-                                NULL,
                                 remoteAdmClientNew,
                                 remoteAdmClientPreExecRestart,
                                 remoteAdmClientFree,
@@ -558,7 +556,7 @@ virLogDaemonSetupNetworkingSystemD(virNetServerPtr logSrv, virNetServerPtr admin
                                              false, 0, 1)))
             return -1;
 
-        if (virNetServerAddService(srv, svc, NULL) < 0) {
+        if (virNetServerAddService(srv, svc) < 0) {
             virObjectUnref(svc);
             return -1;
         }
@@ -579,7 +577,7 @@ virLogDaemonSetupNetworkingNative(virNetServerPtr srv, const char *sock_path)
                                            false, 0, 1)))
         return -1;
 
-    if (virNetServerAddService(srv, svc, NULL) < 0) {
+    if (virNetServerAddService(srv, svc) < 0) {
         virObjectUnref(svc);
         return -1;
     }
