@@ -94,26 +94,6 @@ qemuDriverUnlock(virQEMUDriverPtr driver)
     virMutexUnlock(&driver->lock);
 }
 
-void qemuDomainCmdlineDefFree(qemuDomainCmdlineDefPtr def)
-{
-    size_t i;
-
-    if (!def)
-        return;
-
-    for (i = 0; i < def->num_args; i++)
-        VIR_FREE(def->args[i]);
-    for (i = 0; i < def->num_env; i++) {
-        VIR_FREE(def->env_name[i]);
-        VIR_FREE(def->env_value[i]);
-    }
-    VIR_FREE(def->args);
-    VIR_FREE(def->env_name);
-    VIR_FREE(def->env_value);
-    VIR_FREE(def);
-}
-
-
 #ifndef DEFAULT_LOADER_NVRAM
 # define DEFAULT_LOADER_NVRAM \
     "/usr/share/OVMF/OVMF_CODE.fd:/usr/share/OVMF/OVMF_VARS.fd:" \
@@ -401,6 +381,8 @@ static void virQEMUDriverConfigDispose(void *obj)
 
     VIR_FREE(cfg->memoryBackingDir);
     VIR_FREE(cfg->swtpmStorageDir);
+
+    virStringListFree(cfg->capabilityfilters);
 }
 
 
@@ -1004,13 +986,24 @@ virQEMUDriverConfigLoadSWTPMEntry(virQEMUDriverConfigPtr cfg,
 }
 
 
+static int
+virQEMUDriverConfigLoadCapsFiltersEntry(virQEMUDriverConfigPtr cfg,
+                                        virConfPtr conf)
+{
+    if (virConfGetValueStringList(conf, "capability_filters", false,
+                                  &cfg->capabilityfilters) < 0)
+        return -1;
+
+    return 0;
+}
+
+
 int virQEMUDriverConfigLoadFile(virQEMUDriverConfigPtr cfg,
                                 const char *filename,
                                 bool privileged)
 {
     virConfPtr conf = NULL;
     int ret = -1;
-    char *corestr = NULL;
 
     /* Just check the file is readable before opening it, otherwise
      * libvirt emits an error.
@@ -1074,10 +1067,12 @@ int virQEMUDriverConfigLoadFile(virQEMUDriverConfigPtr cfg,
     if (virQEMUDriverConfigLoadSWTPMEntry(cfg, conf) < 0)
         goto cleanup;
 
+    if (virQEMUDriverConfigLoadCapsFiltersEntry(cfg, conf) < 0)
+        goto cleanup;
+
     ret = 0;
 
  cleanup:
-    VIR_FREE(corestr);
     virConfFree(conf);
     return ret;
 }
