@@ -19,47 +19,46 @@
  * <http://www.gnu.org/licenses/>.
  */
 
-#ifndef LIBVIRT_QEMU_DOMAIN_H
-# define LIBVIRT_QEMU_DOMAIN_H
+#pragma once
 
-# include "virthread.h"
-# include "vircgroup.h"
-# include "virperf.h"
-# include "domain_addr.h"
-# include "domain_conf.h"
-# include "snapshot_conf.h"
-# include "qemu_monitor.h"
-# include "qemu_agent.h"
-# include "qemu_blockjob.h"
-# include "qemu_conf.h"
-# include "qemu_capabilities.h"
-# include "qemu_migration_params.h"
-# include "virmdev.h"
-# include "virchrdev.h"
-# include "virobject.h"
-# include "logging/log_manager.h"
-# include "virdomainmomentobjlist.h"
-# include "virenum.h"
+#include "virthread.h"
+#include "vircgroup.h"
+#include "virperf.h"
+#include "domain_addr.h"
+#include "domain_conf.h"
+#include "snapshot_conf.h"
+#include "qemu_monitor.h"
+#include "qemu_agent.h"
+#include "qemu_blockjob.h"
+#include "qemu_conf.h"
+#include "qemu_capabilities.h"
+#include "qemu_migration_params.h"
+#include "virmdev.h"
+#include "virchrdev.h"
+#include "virobject.h"
+#include "logging/log_manager.h"
+#include "virdomainmomentobjlist.h"
+#include "virenum.h"
 
-# define QEMU_DOMAIN_FORMAT_LIVE_FLAGS \
+#define QEMU_DOMAIN_FORMAT_LIVE_FLAGS \
     (VIR_DOMAIN_XML_SECURE)
 
-# if ULONG_MAX == 4294967295
+#if ULONG_MAX == 4294967295
 /* QEMU has a 64-bit limit, but we are limited by our historical choice of
  * representing bandwidth in a long instead of a 64-bit int.  */
-#  define QEMU_DOMAIN_MIG_BANDWIDTH_MAX ULONG_MAX
-# else
-#  define QEMU_DOMAIN_MIG_BANDWIDTH_MAX (INT64_MAX / (1024 * 1024))
-# endif
+# define QEMU_DOMAIN_MIG_BANDWIDTH_MAX ULONG_MAX
+#else
+# define QEMU_DOMAIN_MIG_BANDWIDTH_MAX (INT64_MAX / (1024 * 1024))
+#endif
 
-# define JOB_MASK(job)                  (job == 0 ? 0 : 1 << (job - 1))
-# define QEMU_JOB_DEFAULT_MASK \
+#define JOB_MASK(job)                  (job == 0 ? 0 : 1 << (job - 1))
+#define QEMU_JOB_DEFAULT_MASK \
     (JOB_MASK(QEMU_JOB_QUERY) | \
      JOB_MASK(QEMU_JOB_DESTROY) | \
      JOB_MASK(QEMU_JOB_ABORT))
 
 /* Jobs which have to be tracked in domain state XML. */
-# define QEMU_DOMAIN_TRACK_JOBS \
+#define QEMU_DOMAIN_TRACK_JOBS \
     (JOB_MASK(QEMU_JOB_DESTROY) | \
      JOB_MASK(QEMU_JOB_ASYNC))
 
@@ -205,7 +204,7 @@ struct _qemuDomainJobObj {
 typedef void (*qemuDomainCleanupCallback)(virQEMUDriverPtr driver,
                                           virDomainObjPtr vm);
 
-# define QEMU_DOMAIN_MASTER_KEY_LEN 32  /* 32 bytes for 256 bit random key */
+#define QEMU_DOMAIN_MASTER_KEY_LEN 32  /* 32 bytes for 256 bit random key */
 
 
 /* helper data types for async device unplug */
@@ -249,8 +248,8 @@ struct _qemuDomainSecretPlain {
     size_t secretlen;
 };
 
-# define QEMU_DOMAIN_AES_IV_LEN 16   /* 16 bytes for 128 bit random */
-                                     /*    initialization vector */
+#define QEMU_DOMAIN_AES_IV_LEN 16   /* 16 bytes for 128 bit random */
+                                    /*    initialization vector */
 typedef struct _qemuDomainSecretAES qemuDomainSecretAES;
 typedef struct _qemuDomainSecretAES *qemuDomainSecretAESPtr;
 struct _qemuDomainSecretAES {
@@ -281,7 +280,6 @@ struct _qemuDomainObjPrivate {
 
     qemuMonitorPtr mon;
     virDomainChrSourceDefPtr monConfig;
-    bool monJSON;
     bool monError;
     unsigned long long monStart;
 
@@ -383,10 +381,10 @@ struct _qemuDomainObjPrivate {
     bool memPrealloc;
 };
 
-# define QEMU_DOMAIN_PRIVATE(vm) \
+#define QEMU_DOMAIN_PRIVATE(vm) \
     ((qemuDomainObjPrivatePtr) (vm)->privateData)
 
-# define QEMU_DOMAIN_DISK_PRIVATE(disk) \
+#define QEMU_DOMAIN_DISK_PRIVATE(disk) \
     ((qemuDomainDiskPrivatePtr) (disk)->privateData)
 
 typedef struct _qemuDomainDiskPrivate qemuDomainDiskPrivate;
@@ -410,7 +408,7 @@ struct _qemuDomainDiskPrivate {
     char *nodeCopyOnRead; /* nodename of the disk-wide copy-on-read blockdev layer */
 };
 
-# define QEMU_DOMAIN_STORAGE_SOURCE_PRIVATE(src) \
+#define QEMU_DOMAIN_STORAGE_SOURCE_PRIVATE(src) \
     ((qemuDomainStorageSourcePrivatePtr) (src)->privateData)
 
 typedef struct _qemuDomainStorageSourcePrivate qemuDomainStorageSourcePrivate;
@@ -447,7 +445,7 @@ struct _qemuDomainVcpuPrivate {
     int vcpus;
 };
 
-# define QEMU_DOMAIN_VCPU_PRIVATE(vcpu) \
+#define QEMU_DOMAIN_VCPU_PRIVATE(vcpu) \
     ((qemuDomainVcpuPrivatePtr) (vcpu)->privateData)
 
 
@@ -460,7 +458,7 @@ struct qemuDomainDiskInfo {
     char *nodename;
 };
 
-# define QEMU_DOMAIN_CHR_SOURCE_PRIVATE(dev) \
+#define QEMU_DOMAIN_CHR_SOURCE_PRIVATE(dev) \
     ((qemuDomainChrSourcePrivatePtr) (dev)->privateData)
 
 typedef struct _qemuDomainChrSourcePrivate qemuDomainChrSourcePrivate;
@@ -483,7 +481,7 @@ struct _qemuDomainVsockPrivate {
 };
 
 
-# define QEMU_DOMAIN_GRAPHICS_PRIVATE(dev) \
+#define QEMU_DOMAIN_GRAPHICS_PRIVATE(dev) \
     ((qemuDomainGraphicsPrivatePtr) (dev)->privateData)
 
 typedef struct _qemuDomainGraphicsPrivate qemuDomainGraphicsPrivate;
@@ -531,6 +529,25 @@ struct _qemuDomainSaveCookie {
     virCPUDefPtr cpu;
 };
 
+
+typedef struct _qemuDomainXmlNsDef qemuDomainXmlNsDef;
+typedef qemuDomainXmlNsDef *qemuDomainXmlNsDefPtr;
+struct _qemuDomainXmlNsDef {
+    size_t num_args;
+    char **args;
+
+    unsigned int num_env;
+    char **env_name;
+    char **env_value;
+
+    size_t ncapsadd;
+    char **capsadd;
+
+    size_t ncapsdel;
+    char **capsdel;
+};
+
+
 qemuDomainSaveCookiePtr qemuDomainSaveCookieNew(virDomainObjPtr vm);
 
 const char *qemuDomainAsyncJobPhaseToString(qemuDomainAsyncJob job,
@@ -1128,5 +1145,3 @@ qemuDomainNVRAMPathGenerate(virQEMUDriverConfigPtr cfg,
 
 virDomainEventSuspendedDetailType
 qemuDomainPausedReasonToSuspendedEvent(virDomainPausedReason reason);
-
-#endif /* LIBVIRT_QEMU_DOMAIN_H */
