@@ -19,15 +19,14 @@
  * <http://www.gnu.org/licenses/>.
  */
 
-#ifndef LIBVIRT_QEMU_MONITOR_JSON_H
-# define LIBVIRT_QEMU_MONITOR_JSON_H
+#pragma once
 
-# include "internal.h"
+#include "internal.h"
 
-# include "qemu_monitor.h"
-# include "virbitmap.h"
-# include "cpu/cpu.h"
-# include "util/virgic.h"
+#include "qemu_monitor.h"
+#include "virbitmap.h"
+#include "cpu/cpu.h"
+#include "util/virgic.h"
 
 int qemuMonitorJSONTransactionAdd(virJSONValuePtr actions,
                                   const char *cmdname,
@@ -317,7 +316,8 @@ int qemuMonitorJSONBlockJobSetSpeed(qemuMonitorPtr mon,
                                     unsigned long long speed)
     ATTRIBUTE_NONNULL(1) ATTRIBUTE_NONNULL(2);
 
-virHashTablePtr qemuMonitorJSONGetAllBlockJobInfo(qemuMonitorPtr mon)
+virHashTablePtr qemuMonitorJSONGetAllBlockJobInfo(qemuMonitorPtr mon,
+                                                  bool rawjobname)
     ATTRIBUTE_NONNULL(1);
 
 int qemuMonitorJSONSetLink(qemuMonitorPtr mon,
@@ -459,12 +459,13 @@ int qemuMonitorJSONGetObjectProps(qemuMonitorPtr mon,
 char *qemuMonitorJSONGetTargetArch(qemuMonitorPtr mon);
 
 int qemuMonitorJSONNBDServerStart(qemuMonitorPtr mon,
-                                  const char *host,
-                                  unsigned int port,
+                                  const virStorageNetHostDef *server,
                                   const char *tls_alias);
 int qemuMonitorJSONNBDServerAdd(qemuMonitorPtr mon,
                                 const char *deviceID,
-                                bool writable);
+                                const char *export,
+                                bool writable,
+                                const char *bitmap);
 int qemuMonitorJSONNBDServerStop(qemuMonitorPtr mon);
 int qemuMonitorJSONGetTPMModels(qemuMonitorPtr mon,
                                 char ***tpmmodels)
@@ -487,9 +488,15 @@ int qemuMonitorJSONGetCPUx86Data(qemuMonitorPtr mon,
                                  const char *property,
                                  virCPUDataPtr *cpudata);
 
+int qemuMonitorJSONGetGuestCPUx86(qemuMonitorPtr mon,
+                                  virCPUDataPtr *data,
+                                  virCPUDataPtr *disabled);
+
 int qemuMonitorJSONGetGuestCPU(qemuMonitorPtr mon,
                                virArch arch,
-                               virCPUDataPtr *data,
+                               qemuMonitorCPUFeatureTranslationCallback translate,
+                               void *opaque,
+                               virCPUDataPtr *enabled,
                                virCPUDataPtr *disabled);
 
 int qemuMonitorJSONRTCResetReinjection(qemuMonitorPtr mon);
@@ -581,5 +588,20 @@ int
 qemuMonitorJSONGetCurrentMachineInfo(qemuMonitorPtr mon,
                                      qemuMonitorCurrentMachineInfoPtr info)
     ATTRIBUTE_NONNULL(1) ATTRIBUTE_NONNULL(2);
+int qemuMonitorJSONAddBitmap(qemuMonitorPtr mon,
+                             const char *node,
+                             const char *bitmap,
+                             bool persistent);
 
-#endif /* LIBVIRT_QEMU_MONITOR_JSON_H */
+int qemuMonitorJSONEnableBitmap(qemuMonitorPtr mon,
+                                const char *node,
+                                const char *bitmap);
+
+int qemuMonitorJSONMergeBitmaps(qemuMonitorPtr mon,
+                                const char *node,
+                                const char *dst,
+                                virJSONValuePtr *src);
+
+int qemuMonitorJSONDeleteBitmap(qemuMonitorPtr mon,
+                                const char *node,
+                                const char *bitmap);
