@@ -18,13 +18,11 @@
  * <http://www.gnu.org/licenses/>.
  */
 
-#ifndef LIBVIRT_QEMU_SECURITY_H
-# define LIBVIRT_QEMU_SECURITY_H
+#pragma once
 
-
-# include "qemu_conf.h"
-# include "domain_conf.h"
-# include "security/security_manager.h"
+#include "qemu_conf.h"
+#include "domain_conf.h"
+#include "security/security_manager.h"
 
 int qemuSecuritySetAllLabel(virQEMUDriverPtr driver,
                             virDomainObjPtr vm,
@@ -101,28 +99,26 @@ int qemuSecurityRestoreSavedStateLabel(virQEMUDriverPtr driver,
 /* Please note that for these APIs there is no wrapper yet. Do NOT blindly add
  * new APIs here. If an API can touch a file add a proper wrapper instead.
  */
-# define qemuSecurityCheckAllLabel virSecurityManagerCheckAllLabel
-# define qemuSecurityClearSocketLabel virSecurityManagerClearSocketLabel
-# define qemuSecurityGenLabel virSecurityManagerGenLabel
-# define qemuSecurityGetBaseLabel virSecurityManagerGetBaseLabel
-# define qemuSecurityGetDOI virSecurityManagerGetDOI
-# define qemuSecurityGetModel virSecurityManagerGetModel
-# define qemuSecurityGetMountOptions virSecurityManagerGetMountOptions
-# define qemuSecurityGetNested virSecurityManagerGetNested
-# define qemuSecurityGetProcessLabel virSecurityManagerGetProcessLabel
-# define qemuSecurityNew virSecurityManagerNew
-# define qemuSecurityNewDAC virSecurityManagerNewDAC
-# define qemuSecurityNewStack virSecurityManagerNewStack
-# define qemuSecurityPostFork virSecurityManagerPostFork
-# define qemuSecurityPreFork virSecurityManagerPreFork
-# define qemuSecurityReleaseLabel virSecurityManagerReleaseLabel
-# define qemuSecurityReserveLabel virSecurityManagerReserveLabel
-# define qemuSecuritySetChildProcessLabel virSecurityManagerSetChildProcessLabel
-# define qemuSecuritySetDaemonSocketLabel virSecurityManagerSetDaemonSocketLabel
-# define qemuSecuritySetImageFDLabel virSecurityManagerSetImageFDLabel
-# define qemuSecuritySetSocketLabel virSecurityManagerSetSocketLabel
-# define qemuSecuritySetTapFDLabel virSecurityManagerSetTapFDLabel
-# define qemuSecurityStackAddNested virSecurityManagerStackAddNested
-# define qemuSecurityVerify virSecurityManagerVerify
-
-#endif /* LIBVIRT_QEMU_SECURITY_H */
+#define qemuSecurityCheckAllLabel virSecurityManagerCheckAllLabel
+#define qemuSecurityClearSocketLabel virSecurityManagerClearSocketLabel
+#define qemuSecurityGenLabel virSecurityManagerGenLabel
+#define qemuSecurityGetBaseLabel virSecurityManagerGetBaseLabel
+#define qemuSecurityGetDOI virSecurityManagerGetDOI
+#define qemuSecurityGetModel virSecurityManagerGetModel
+#define qemuSecurityGetMountOptions virSecurityManagerGetMountOptions
+#define qemuSecurityGetNested virSecurityManagerGetNested
+#define qemuSecurityGetProcessLabel virSecurityManagerGetProcessLabel
+#define qemuSecurityNew virSecurityManagerNew
+#define qemuSecurityNewDAC virSecurityManagerNewDAC
+#define qemuSecurityNewStack virSecurityManagerNewStack
+#define qemuSecurityPostFork virSecurityManagerPostFork
+#define qemuSecurityPreFork virSecurityManagerPreFork
+#define qemuSecurityReleaseLabel virSecurityManagerReleaseLabel
+#define qemuSecurityReserveLabel virSecurityManagerReserveLabel
+#define qemuSecuritySetChildProcessLabel virSecurityManagerSetChildProcessLabel
+#define qemuSecuritySetDaemonSocketLabel virSecurityManagerSetDaemonSocketLabel
+#define qemuSecuritySetImageFDLabel virSecurityManagerSetImageFDLabel
+#define qemuSecuritySetSocketLabel virSecurityManagerSetSocketLabel
+#define qemuSecuritySetTapFDLabel virSecurityManagerSetTapFDLabel
+#define qemuSecurityStackAddNested virSecurityManagerStackAddNested
+#define qemuSecurityVerify virSecurityManagerVerify
