@@ -32,7 +32,6 @@
 #include "virutil.h"
 #include "virfile.h"
 #include "virnetserver.h"
-#include "virnetservermdns.h"
 #include "virdbus.h"
 #include "virhash.h"
 #include "virstring.h"
@@ -767,16 +766,6 @@ virNetDaemonUpdateServices(virNetDaemonPtr dmn,
     virObjectUnlock(dmn);
 }
 
-static int
-daemonServerRun(void *payload,
-                const void *key ATTRIBUTE_UNUSED,
-                void *opaque ATTRIBUTE_UNUSED)
-{
-    virNetServerPtr srv = payload;
-
-    return virNetServerStart(srv);
-};
-
 static int
 daemonServerProcessClients(void *payload,
                            const void *key ATTRIBUTE_UNUSED,
@@ -802,9 +791,6 @@ virNetDaemonRun(virNetDaemonPtr dmn)
         goto cleanup;
     }
 
-    if (virHashForEach(dmn->servers, daemonServerRun, NULL) < 0)
-        goto cleanup;
-
     dmn->quit = false;
 
     if (dmn->autoShutdownTimeout &&
