@@ -16,13 +16,12 @@
  * <http://www.gnu.org/licenses/>.
  */
 
-#ifndef LIBVIRT_SECURITY_DRIVER_H
-# define LIBVIRT_SECURITY_DRIVER_H
+#pragma once
 
-# include "internal.h"
-# include "domain_conf.h"
+#include "internal.h"
+#include "domain_conf.h"
 
-# include "security_manager.h"
+#include "security_manager.h"
 
 /*
  * Return values for security driver probing: the driver will determine
@@ -216,5 +215,3 @@ struct _virSecurityDriver {
 
 virSecurityDriverPtr virSecurityDriverLookup(const char *name,
                                              const char *virtDriver);
-
-#endif /* LIBVIRT_SECURITY_DRIVER_H */
