@@ -258,10 +258,10 @@ virStorageFileBackendGlusterReadlinkCallback(const char *path,
                                              void *data)
 {
     virStorageFileBackendGlusterPrivPtr priv = data;
-    char *buf = NULL;
     size_t bufsiz = 0;
     ssize_t ret;
     struct stat st;
+    VIR_AUTOFREE(char *) buf = NULL;
 
     *linkpath = NULL;
 
@@ -277,13 +277,13 @@ virStorageFileBackendGlusterReadlinkCallback(const char *path,
 
  realloc:
     if (VIR_EXPAND_N(buf, bufsiz, 256) < 0)
-        goto error;
+        return -1;
 
     if ((ret = glfs_readlink(priv->vol, path, buf, bufsiz)) < 0) {
         virReportSystemError(errno,
                              _("failed to read link of gluster file '%s'"),
                              path);
-        goto error;
+        return -1;
     }
 
     if (ret == bufsiz)
@@ -291,13 +291,9 @@ virStorageFileBackendGlusterReadlinkCallback(const char *path,
 
     buf[ret] = '\0';
 
-    *linkpath = buf;
+    VIR_STEAL_PTR(*linkpath, buf);
 
     return 0;
-
- error:
-    VIR_FREE(buf);
-    return -1;
 }
 
 
@@ -305,7 +301,7 @@ static const char *
 virStorageFileBackendGlusterGetUniqueIdentifier(virStorageSourcePtr src)
 {
     virStorageFileBackendGlusterPrivPtr priv = src->drv->priv;
-    char *filePath = NULL;
+    VIR_AUTOFREE(char *) filePath = NULL;
 
     if (priv->canonpath)
         return priv->canonpath;
@@ -321,8 +317,6 @@ virStorageFileBackendGlusterGetUniqueIdentifier(virStorageSourcePtr src)
                              src->volume,
                              filePath));
 
-    VIR_FREE(filePath);
-
     return priv->canonpath;
 }
 
