@@ -19,11 +19,10 @@
  *
  */
 
-#ifndef LIBVIRT_VIRAUDIT_H
-# define LIBVIRT_VIRAUDIT_H
+#pragma once
 
-# include "internal.h"
-# include "virlog.h"
+#include "internal.h"
+#include "virlog.h"
 
 typedef enum {
     VIR_AUDIT_RECORD_MACHINE_CONTROL,
@@ -46,15 +45,13 @@ char *virAuditEncode(const char *key, const char *value);
 
 void virAuditClose(void);
 
-# define VIR_AUDIT(type, success, ...) \
+#define VIR_AUDIT(type, success, ...) \
     virAuditSend(&virLogSelf, __FILE__, __LINE__, __func__, \
                  NULL, NULL, type, success, __VA_ARGS__);
 
-# define VIR_AUDIT_USER(type, success, clienttty, clientaddr, ...) \
+#define VIR_AUDIT_USER(type, success, clienttty, clientaddr, ...) \
     virAuditSend(&virLogSelf, __FILE__, __LINE__, __func__, \
                  clienttty, clientaddr, type, success, __VA_ARGS__);
 
-# define VIR_AUDIT_STR(str) \
+#define VIR_AUDIT_STR(str) \
     ((str) ? (str) : "?")
-
-#endif /* LIBVIRT_VIRAUDIT_H */
