@@ -24,6 +24,7 @@
 #include "virerror.h"
 #include "virfile.h"
 #include "virstring.h"
+#include "viralloc.h"
 
 #define VIR_FROM_THIS VIR_FROM_NONE
 
@@ -46,7 +47,8 @@ struct _virMediatedDeviceList {
     virMediatedDevicePtr *devs;
 };
 
-VIR_ENUM_IMPL(virMediatedDeviceModel, VIR_MDEV_MODEL_TYPE_LAST,
+VIR_ENUM_IMPL(virMediatedDeviceModel,
+              VIR_MDEV_MODEL_TYPE_LAST,
               "vfio-pci",
               "vfio-ccw",
               "vfio-ap",
