@@ -32,7 +32,8 @@
 
 VIR_LOG_INIT("util.secret");
 
-VIR_ENUM_IMPL(virSecretUsage, VIR_SECRET_USAGE_TYPE_LAST,
+VIR_ENUM_IMPL(virSecretUsage,
+              VIR_SECRET_USAGE_TYPE_LAST,
               "none", "volume", "ceph", "iscsi", "tls",
 );
 
