@@ -19,14 +19,13 @@
  *
  */
 
-#ifndef LIBVIRT_VMX_H
-# define LIBVIRT_VMX_H
+#pragma once
 
-# include "internal.h"
-# include "virconf.h"
-# include "domain_conf.h"
+#include "internal.h"
+#include "virconf.h"
+#include "domain_conf.h"
 
-# define VMX_CONFIG_FORMAT_ARGV "vmware-vmx"
+#define VMX_CONFIG_FORMAT_ARGV "vmware-vmx"
 
 typedef struct _virVMXContext virVMXContext;
 
@@ -66,15 +65,15 @@ struct _virVMXContext {
 
 char *virVMXEscapeHex(const char *string, char escape, const char *special);
 
-# define virVMXEscapeHexPipe(_string) virVMXEscapeHex(_string, '|', "\"")
+#define virVMXEscapeHexPipe(_string) virVMXEscapeHex(_string, '|', "\"")
 
-# define virVMXEscapeHexPercent(_string) virVMXEscapeHex(_string, '%', "/\\")
+#define virVMXEscapeHexPercent(_string) virVMXEscapeHex(_string, '%', "/\\")
 
 int virVMXUnescapeHex(char *string, char escape);
 
-# define virVMXUnescapeHexPipe(_string) virVMXUnescapeHex(_string, '|')
+#define virVMXUnescapeHexPipe(_string) virVMXUnescapeHex(_string, '|')
 
-# define virVMXUnescapeHexPercent(_string) virVMXUnescapeHex(_string, '%')
+#define virVMXUnescapeHexPercent(_string) virVMXUnescapeHex(_string, '%')
 
 char *virVMXConvertToUTF8(const char *encoding, const char *string);
 
@@ -141,5 +140,3 @@ int virVMXFormatParallel(virVMXContext *ctx, virDomainChrDefPtr def,
                          virBufferPtr buffer);
 
 int virVMXFormatSVGA(virDomainVideoDefPtr def, virBufferPtr buffer);
-
-#endif /* LIBVIRT_VMX_H */
