@@ -23,17 +23,16 @@
  * <http://www.gnu.org/licenses/>.
  */
 
-#ifndef LIBVIRT_NSS_H
-# define LIBVIRT_NSS_H
+#pragma once
 
-# include <nss.h>
-# include <netdb.h>
+#include <nss.h>
+#include <netdb.h>
 
-# if !defined(LIBVIRT_NSS_GUEST)
-#  define NSS_NAME(s) _nss_libvirt_##s##_r
-# else
-#  define NSS_NAME(s) _nss_libvirt_guest_##s##_r
-# endif
+#if !defined(LIBVIRT_NSS_GUEST)
+# define NSS_NAME(s) _nss_libvirt_##s##_r
+#else
+# define NSS_NAME(s) _nss_libvirt_guest_##s##_r
+#endif
 
 enum nss_status
 NSS_NAME(gethostbyname)(const char *name, struct hostent *result,
@@ -48,17 +47,15 @@ enum nss_status
 NSS_NAME(gethostbyname3)(const char *name, int af, struct hostent *result,
                          char *buffer, size_t buflen, int *errnop,
                          int *herrnop, int32_t *ttlp, char **canonp);
-# ifdef HAVE_STRUCT_GAIH_ADDRTUPLE
+#ifdef HAVE_STRUCT_GAIH_ADDRTUPLE
 enum nss_status
 NSS_NAME(gethostbyname4)(const char *name, struct gaih_addrtuple **pat,
                          char *buffer, size_t buflen, int *errnop,
                          int *herrnop, int32_t *ttlp);
-# endif /* HAVE_STRUCT_GAIH_ADDRTUPLE */
+#endif /* HAVE_STRUCT_GAIH_ADDRTUPLE */
 
-# if defined(HAVE_BSD_NSS)
+#if defined(HAVE_BSD_NSS)
 ns_mtab*
 nss_module_register(const char *name, unsigned int *size,
                     nss_module_unregister_fn *unregister);
-# endif /* HAVE_BSD_NSS */
-
-#endif /* LIBVIRT_NSS_H */
+#endif /* HAVE_BSD_NSS */
