@@ -408,6 +408,56 @@ virshNetworkEventNameCompleter(vshControl *ctl ATTRIBUTE_UNUSED,
 }
 
 
+char **
+virshNetworkPortUUIDCompleter(vshControl *ctl,
+                              const vshCmd *cmd ATTRIBUTE_UNUSED,
+                              unsigned int flags)
+{
+    virshControlPtr priv = ctl->privData;
+    virNetworkPtr net = NULL;
+    virNetworkPortPtr *ports = NULL;
+    int nports = 0;
+    size_t i = 0;
+    char **ret = NULL;
+
+    virCheckFlags(0, NULL);
+
+    if (!priv->conn || virConnectIsAlive(priv->conn) <= 0)
+        return NULL;
+
+    if (!(net = virshCommandOptNetwork(ctl, cmd, NULL)))
+        return false;
+
+    if ((nports = virNetworkListAllPorts(net, &ports, flags)) < 0)
+        return NULL;
+
+    if (VIR_ALLOC_N(ret, nports + 1) < 0)
+        goto error;
+
+    for (i = 0; i < nports; i++) {
+        char uuid[VIR_UUID_STRING_BUFLEN];
+
+        if (virNetworkPortGetUUIDString(ports[i], uuid) < 0 ||
+            VIR_STRDUP(ret[i], uuid) < 0)
+            goto error;
+
+        virNetworkPortFree(ports[i]);
+    }
+    VIR_FREE(ports);
+
+    return ret;
+
+ error:
+    for (; i < nports; i++)
+        virNetworkPortFree(ports[i]);
+    VIR_FREE(ports);
+    for (i = 0; i < nports; i++)
+        VIR_FREE(ret[i]);
+    VIR_FREE(ret);
+    return NULL;
+}
+
+
 char **
 virshNodeDeviceNameCompleter(vshControl *ctl,
                              const vshCmd *cmd ATTRIBUTE_UNUSED,
