@@ -18,46 +18,45 @@
  * <http://www.gnu.org/licenses/>.
  */
 
-#ifndef LIBVIRT_VIRSH_H
-# define LIBVIRT_VIRSH_H
+#pragma once
 
-# include <stdarg.h>
-# include <unistd.h>
-# include <sys/stat.h>
-# include <termios.h>
+#include <stdarg.h>
+#include <unistd.h>
+#include <sys/stat.h>
+#include <termios.h>
 
-# include "internal.h"
-# include "virerror.h"
-# include "virthread.h"
-# include "virpolkit.h"
-# include "vsh.h"
-# include "virsh-completer.h"
+#include "internal.h"
+#include "virerror.h"
+#include "virthread.h"
+#include "virpolkit.h"
+#include "vsh.h"
+#include "virsh-completer.h"
 
-# define VIRSH_PROMPT_RW    "virsh # "
-# define VIRSH_PROMPT_RO    "virsh > "
+#define VIRSH_PROMPT_RW    "virsh # "
+#define VIRSH_PROMPT_RO    "virsh > "
 
-# define VIR_FROM_THIS VIR_FROM_NONE
+#define VIR_FROM_THIS VIR_FROM_NONE
 
 /*
  * Command group types
  */
-# define VIRSH_CMD_GRP_DOM_MANAGEMENT   "Domain Management"
-# define VIRSH_CMD_GRP_DOM_MONITORING   "Domain Monitoring"
-# define VIRSH_CMD_GRP_STORAGE_POOL     "Storage Pool"
-# define VIRSH_CMD_GRP_STORAGE_VOL      "Storage Volume"
-# define VIRSH_CMD_GRP_NETWORK          "Networking"
-# define VIRSH_CMD_GRP_NODEDEV          "Node Device"
-# define VIRSH_CMD_GRP_IFACE            "Interface"
-# define VIRSH_CMD_GRP_NWFILTER         "Network Filter"
-# define VIRSH_CMD_GRP_SECRET           "Secret"
-# define VIRSH_CMD_GRP_SNAPSHOT         "Snapshot"
-# define VIRSH_CMD_GRP_HOST_AND_HV      "Host and Hypervisor"
-# define VIRSH_CMD_GRP_VIRSH            "Virsh itself"
+#define VIRSH_CMD_GRP_DOM_MANAGEMENT   "Domain Management"
+#define VIRSH_CMD_GRP_DOM_MONITORING   "Domain Monitoring"
+#define VIRSH_CMD_GRP_STORAGE_POOL     "Storage Pool"
+#define VIRSH_CMD_GRP_STORAGE_VOL      "Storage Volume"
+#define VIRSH_CMD_GRP_NETWORK          "Networking"
+#define VIRSH_CMD_GRP_NODEDEV          "Node Device"
+#define VIRSH_CMD_GRP_IFACE            "Interface"
+#define VIRSH_CMD_GRP_NWFILTER         "Network Filter"
+#define VIRSH_CMD_GRP_SECRET           "Secret"
+#define VIRSH_CMD_GRP_SNAPSHOT         "Snapshot"
+#define VIRSH_CMD_GRP_HOST_AND_HV      "Host and Hypervisor"
+#define VIRSH_CMD_GRP_VIRSH            "Virsh itself"
 
 /*
  * Common command options
  */
-# define VIRSH_COMMON_OPT_POOL(_helpstr, cflags) \
+#define VIRSH_COMMON_OPT_POOL(_helpstr, cflags) \
     {.name = "pool", \
      .type = VSH_OT_DATA, \
      .flags = VSH_OFLAG_REQ, \
@@ -66,7 +65,7 @@
      .completer_flags = cflags, \
     }
 
-# define VIRSH_COMMON_OPT_DOMAIN(_helpstr, cflags) \
+#define VIRSH_COMMON_OPT_DOMAIN(_helpstr, cflags) \
     {.name = "domain", \
      .type = VSH_OT_DATA, \
      .flags = VSH_OFLAG_REQ, \
@@ -75,35 +74,35 @@
      .completer_flags = cflags, \
     }
 
-# define VIRSH_COMMON_OPT_DOMAIN_FULL(cflags) \
+#define VIRSH_COMMON_OPT_DOMAIN_FULL(cflags) \
     VIRSH_COMMON_OPT_DOMAIN(N_("domain name, id or uuid"), cflags)
 
-# define VIRSH_COMMON_OPT_CONFIG(_helpstr) \
+#define VIRSH_COMMON_OPT_CONFIG(_helpstr) \
     {.name = "config", \
      .type = VSH_OT_BOOL, \
      .help = _helpstr \
     }
 
-# define VIRSH_COMMON_OPT_LIVE(_helpstr) \
+#define VIRSH_COMMON_OPT_LIVE(_helpstr) \
     {.name = "live", \
      .type = VSH_OT_BOOL, \
      .help = _helpstr \
     }
 
-# define VIRSH_COMMON_OPT_CURRENT(_helpstr) \
+#define VIRSH_COMMON_OPT_CURRENT(_helpstr) \
     {.name = "current", \
      .type = VSH_OT_BOOL, \
      .help = _helpstr \
     }
 
-# define VIRSH_COMMON_OPT_FILE(_helpstr) \
+#define VIRSH_COMMON_OPT_FILE(_helpstr) \
     {.name = "file", \
      .type = VSH_OT_DATA, \
      .flags = VSH_OFLAG_REQ, \
      .help = _helpstr \
     }
 
-# define VIRSH_COMMON_OPT_DOMAIN_OT_STRING(_helpstr, oflags, cflags) \
+#define VIRSH_COMMON_OPT_DOMAIN_OT_STRING(_helpstr, oflags, cflags) \
     {.name = "domain", \
      .type = VSH_OT_STRING, \
      .flags = oflags, \
@@ -112,11 +111,11 @@
      .completer_flags = cflags, \
     }
 
-# define VIRSH_COMMON_OPT_DOMAIN_OT_STRING_FULL(oflags, cflags) \
+#define VIRSH_COMMON_OPT_DOMAIN_OT_STRING_FULL(oflags, cflags) \
     VIRSH_COMMON_OPT_DOMAIN_OT_STRING(N_("domain name, id or uuid"), \
                                       oflags, cflags)
 
-# define VIRSH_COMMON_OPT_DOMAIN_OT_ARGV(_helpstr, cflags) \
+#define VIRSH_COMMON_OPT_DOMAIN_OT_ARGV(_helpstr, cflags) \
     {.name = "domain", \
      .type = VSH_OT_ARGV, \
      .flags = VSH_OFLAG_NONE, \
@@ -125,7 +124,7 @@
      .completer_flags = cflags, \
     }
 
-# define VIRSH_COMMON_OPT_DOMAIN_OT_ARGV_FULL(cflags) \
+#define VIRSH_COMMON_OPT_DOMAIN_OT_ARGV_FULL(cflags) \
     VIRSH_COMMON_OPT_DOMAIN_OT_ARGV(N_("domain name, id or uuid"), cflags)
 
 typedef struct _virshControl virshControl;
@@ -171,5 +170,3 @@ typedef enum {
 } virshLookupByFlags;
 
 virConnectPtr virshConnect(vshControl *ctl, const char *uri, bool readonly);
-
-#endif /* LIBVIRT_VIRSH_H */
